@@ -28,6 +28,7 @@ from tempest import manager
 
 from zun_tempest_plugin.tests.tempest.api.models import capsule_model
 from zun_tempest_plugin.tests.tempest.api.models import container_model
+from zun_tempest_plugin.tests.tempest.api.models import host_model
 from zun_tempest_plugin.tests.tempest.api.models import service_model
 from zun_tempest_plugin.tests.tempest import utils
 
@@ -206,6 +207,11 @@ class ZunClient(rest_client.RestClient):
 
         return url
 
+    @classmethod
+    def hosts_uri(cls):
+        url = "/hosts/"
+        return url
+
     def post_container(self, model, **kwargs):
         """Makes POST /container request
 
@@ -408,6 +414,11 @@ class ZunClient(rest_client.RestClient):
     def delete_network(self, network_id, params=None):
         return self.delete(self.network_uri(network_id, params=params))
 
+    def list_hosts(self, **kwargs):
+        resp, body = self.get(self.hosts_uri(), **kwargs)
+        return self.deserialize(resp, body,
+                                host_model.HostCollection)
+
 
 @contextlib.contextmanager
 def docker_client(docker_auth_url):
